==> developer-center-api-1.0.8.zhengjy-20160825.111842-8-sources.jar: cn/com/duiba/developer/center/api/remoteservice/RemoteInternalLetterService.java <==
package cn.com.duiba.developer.center.api.remoteservice;

import cn.com.duiba.developer.center.api.domain.manager.InternalLetterDO;
import cn.com.duiba.developer.center.api.domain.manager.InternalLetterKeyDO;
import cn.com.duiba.developer.center.api.domain.paramquery.InternalLetterQueryEntity;
import cn.com.duiba.developer.center.api.domain.paramquery.PageQueryEntity;
import cn.com.duiba.developer.center.api.domain.vo.PaginationVO;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * Created by liuyao on 16/7/18.
 */
public interface RemoteInternalLetterService {
    /**
     * 管理员保存站内信
     *
     * @param letter 站内信
     * @return 库存数量
     */
    public DubboResult<Boolean> saveInternalLetter(InternalLetterDO letter);

    /**
     * 删除站内信
     *
     * @param letterId 站内信Id
     * @return 是否成功
     */
    public DubboResult<Boolean> deleteInternalLetter(Long letterId);

    /**
     *重载  开发者删除站内信
     *
     * @param developerId 开发者Id letterId 站内信Id
     * @return 是否成功
     */
    public DubboResult<Boolean> deleteInternalLetter(Long developerId,Long letterId);

    /**
     *  获取站内信详情
     *
     * @param letterId 站内信Id
     * @return 是否成功
     */
    public DubboResult<InternalLetterDO> getOneInternalLetter(Long letterId);

    /**
     *  管理员获取站内信列表
     *
     * @param param 分页参数
     * @return PaginationVO
     */
    public DubboResult<PaginationVO<InternalLetterDO>> getInternalLetterPage(InternalLetterQueryEntity param);
    /**
     * 开发者获取站内信列表
     *
     * @param param 分页参数
     * @return PaginationVO
     */
    public DubboResult<PaginationVO<InternalLetterKeyDO>> getInternalLetterKeyPage(InternalLetterQueryEntity param);
    /**
     * 开发者设置所有的站内信为已读
     *
     * @param developerId 开发者Id
     * @return PaginationVO
     */
    public DubboResult<Integer> setAllReaded(Long developerId);
    /**
     * 开发者加载站内信详情
     * @param developerId 开发者Id
     * @return PaginationVO
     */
    public DubboResult<InternalLetterDO> developerFindInternalLetter(Long developerId,Long letterId);
    /**
     * 开发者获取未读条数
     * @param developerId 开发者Id
     * @return PaginationVO
     */
    public DubboResult<Integer> getNoRead(Long developerId);
}

==> developer-center-api-1.7.5.zhengjy-20170220.083131-1-sources.jar: cn/com/duiba/developer/center/api/remoteservice/RemoteInternalLetterService.java <==
package cn.com.duiba.developer.center.api.remoteservice;

import java.util.List;
import java.util.Map;

import cn.com.duiba.developer.center.api.domain.manager.InternalLetterDO;
import cn.com.duiba.developer.center.api.domain.manager.InternalLetterKeyDO;
import cn.com.duiba.developer.center.api.domain.paramquery.InternalLetterQueryEntity;
import cn.com.duiba.developer.center.api.domain.vo.PaginationVO;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * Created by liuyao on 16/7/18.
 */
public interface RemoteInternalLetterService {
    /**
     * 管理员保存站内信
     *
     * @param letter 站内信
     * @return 库存数量
     */
    public DubboResult<Boolean> saveInternalLetter(InternalLetterDO letter);

    /**
     * 删除站内信
     *
     * @param letterId 站内信Id
     * @return 是否成功
     */
    public DubboResult<Boolean> deleteInternalLetter(Long letterId);

    /**
     *重载  开发者删除站内信
     *
     * @param developerId 开发者Id
     * @param letterId 站内信Id
     * @return 是否成功
     */
    public DubboResult<Boolean> deleteInternalLetter(Long developerId,Long letterId);

    /**
     *  获取站内信详情
     *
     * @param letterId 站内信Id
     * @return 是否成功
     */
    public DubboResult<InternalLetterDO> getOneInternalLetter(Long letterId);

    /**
     *  管理员获取站内信列表
     *
     * @param param 分页参数
     * @return PaginationVO
     */
    public DubboResult<PaginationVO<InternalLetterDO>> getInternalLetterPage(InternalLetterQueryEntity param);
    /**
     * 开发者获取站内信列表
     *
     * @param param 分页参数
     * @return PaginationVO
     */
    public DubboResult<PaginationVO<InternalLetterKeyDO>> getInternalLetterKeyPage(InternalLetterQueryEntity param);
    /**
     * 开发者设置所有的站内信为已读
     *
     * @param developerId 开发者Id
     * @return PaginationVO
     */
    public DubboResult<Integer> setAllReaded(Long developerId);
    /**
     * 开发者加载站内信详情
     * @param developerId 开发者Id
     * @param letterId 站内信Id
     * @return PaginationVO
     */
    public DubboResult<InternalLetterDO> developerFindInternalLetter(Long developerId,Long letterId);
    /**
     * 开发者获取未读条数
     * @param developerId 开发者Id
     * @return PaginationVO
     */
    public DubboResult<Integer> getNoRead(Long developerId);
    /**
     * 查询所有
     * @param developerId开发者ID
     */
    public DubboResult<List<InternalLetterKeyDO>> findAll(Long developerId);
    /**
     * 查询所有
     * @param ids
     */
    public DubboResult<List<InternalLetterDO>> findByIds(List<Long> ids);
}
